/*
====================
		EXAMPLE SCRIPT FOR TEXT BOXES AND SIMPLE WARPS
		Vincent Beers, 2005
		http://DaVince.websitemaster.org/
		http://DaVince.sitesled.com/
		Email: VincentBeers@yahoo.com

	This small example game will show you how to make a textbox, so you can "talk" to people,
	and it will also show you how to make the player "warp" to other maps or positions, fade effect
	included.
	The example game also explains some Sphere basics.
	
====================

Note that this text is green, because it is a comment.
It was MADE a comment because it is between the /* and * /.
(I left a space in the last one because otherwise all the other text wouldn't be
a comment anymore, but code.)

I marked all lines of code within a comment with tabs.
Finally, don't forget to put a ; after most lines of code! It is neccesary for the engine because
it would be a . for the end of a sentence to us.
*/



//========================
//		ABOUT FUNCTIONS
//========================

/*
If you make new function, you can call them later with FunctionName();
So if you make a function Blah(), you can start it by typing:
	Blah();

To make the function, type:
	function FunctionName()

You can also make parameters in the functions:
	function Blah(x, y)
This function will have two user input options, x and y, seperated by a comma.
It enables to let the scripter use functions more extended (ex. variable positions for warps).

You can, for example, call this function with:
	Blah(4, 5);
This will start the function Blah, and pass the parameters 4 for x and 5 for y to it.

To open the function for code, use {
And to close the function code, use }
{, } and the function don't get a ; after them.
	function Blah(x, y)
	{
		//Code here.
	}

You can add in code in the functions which will read the parameters. For example:
	function Blah(x, y)
	{
		SetPersonX("person", x);
		SetPersonX("person", y);
	}
This example function has 2 lines of code.
The SetPersonX looks for its value in the parameter x, and the same goes for y, but for y.

So Blah(2, 8); will make the function start SetPersonX("person", 2); and SetPersonX("person", 8);
This is very useful for customizing functions and making the output more free.

Finally, to start making your game, your start function MUST be called game() and it must NOT
have any parameters.
*/


//Start function.
function game()
{
	//This creates a new person. The first parameter gives it a name, the second one a spriteset file and
	//the third one tells the engine wheter the person should be destroyed when the player is changing maps.
	//Since this will be our main person, he shouldn't. So the value for param 3 is false.
	CreatePerson("person", "ball.rss", false);
	
	//This will become the player, so let's give him input to move around.
	AttachInput("person");
	
	//And let's make sure the camera's always pointed at him (in normal circumstances).
	AttachCamera("person");

//Let's play MUSIC!
//Look at line 61 for more info about 'var'.
var Music = LoadSound("OpenPod.mid");

//Music has some properties. You can get it to play with .play() and you can stop it with .stop().
//.play has one parameter: should it be looping? For music this is true. For a one time sample it's false.
//	Music.play(looping?);
Music.play(true);

//Set it to false if you want the music to only play once, or comment it by putting // in front of it!

//Let's start the map engine. Parameter 1 will open the map file (CASE SENSITIVE) and param 2
//is the fps (frames per second). Don't set this too high - the game will run too fast!
//For fps, a value of 50 - 60 is ok.
MapEngine("ExampleMap.rmp", 60);
}



//========================
//		TEXTBOX
//========================

//Let's make a new function called TextBox. It will have the parameter text. NO ; AFTER IT!
function TextBox(text)

//open the function for code. NO ; AFTER IT!
{

/*
Let's make a variable. This enables the user to use words instead of values, because those words
will then CONTAIN the values. Example: blah = 4 so blah + blah = 8.
Variables can store numbers (4), strings ("Hehehe"), and files (LoadFont, LoadWindowStyle, LoadSound etc).
Variables can be made by typing var. After the var comes the variable name.
	var Blah;

After the name you can put something optional: a value.
This is done by using = and then the value. Don't forget to put ; after the line. It's still code!
	var Blah = 88;
	var Bleh = "Some string, eh?";
*/

  //Lets make a new variable with the name font, and let's give it the value to
  //read a file (the system font in this case, useful for test games).
  var font = GetSystemFont();
  
  //Let's make variables for other stuff.
  var windowstyle = GetSystemWindowStyle();
  var x = 16;
  var y = 16;
  var width = GetScreenWidth() - 32;
  var height = font.getStringHeight(text, width);
  
  /*DRAWING STUFF
  This is special, because when you type drawing commands (Line, Rectangle, font.draw), it doesn't
  seem to do anything. But it DOES do something. It draws on the backbuffer, which is in the memory.
  If you want to  put everything in the backbuffer on-screen, you'd have to use FlipScreen() to 'turn the
  screen around' to show it on-screen.
  
  First, let's render our map on the screen so the textbox shows in the map.
  We are going to use a condition: the map engine must be running before rendering the map.
  If it's true that the map engine is running...*/
  if (IsMapEngineRunning() == true)
  {	//Open code again
	RenderMap();	//Render our map.
  }	//Close code.
  
  /*
  Let's draw the window. Normally We'd have to type
  GetSystemWindowStyle().drawWindow(16, 16, GetScreenWidth() - 32, font.getStringHeight(text, GetScreenWidth() - 32))
  That's too long, and this is where we are going to use our variables. To use them, just type their name.
  */
  windowstyle.drawWindow(x, y, width, height);
  
  /*
  Now let's draw the text on it.
  This should be AFTER the window code because otherwise the text would be behind the window.
  the code for drawing text is
		FONT_VARIABLE.drawTextBox(x, y, width, height, 0, "the string");
  Thus, you'd havee to make a font variable ( var FontThing = LoadFont(filename); ).
  
  We are going to use our text parameter here for the string. Because we're going to read a string that's
  behind the text parameter, we don't use the "" at the string parameter because otherwise the function
  would always return "text" instead of what's defined INSIDE the text parameter.
  If you call the textbox function, though (which contains one parameter called text, there's the code
  coming from), you'll have to use TextBox("Text within those, erm, thingees");
  */
  font.drawTextBox(x, y, width, height, 0, text);
  
  //Now, let's draw all our created stuff on the screen. You only drew in the backbuffer, see,
  //and not on the screen.
  FlipScreen();
  
  //Now pause until we press any key.
  GetKey();
  
//Now close our function TextBox.
}


//		WARP FUNCTION
//new function. This will be pretty clear if you read the previous stuff.
function Warp(map, x, y)
{
//We will call our custom function, FadeOut here! With a parameter, which we will give the value 3!
FadeOut(3);

//Let's change to a new map which is defined by the user (look at the param above!).
ChangeMap(map);
SetPersonX("person", x * 16 + 5);
SetPersonY("person", y * 16 + 5);
//The + 5 is to set the position a bit more correctly. Remove it to see what I mean! ;)
//You may edit the +5 a bit in your own game, depending on your spriteset's size.

//And another of our own functions, FadeIn.
FadeIn(3);
}



function FadeOut(speed)
{
var i = 0;
var FadeColor;

//GetScreenHeight() and GetScreenWidth() get your screen's height and width.
//We'll put them in a variable for easier access (typing SW is much faster than GetScreenWidth()).
var SW = GetScreenWidth();
var SH = GetScreenHeight();

//GrabImage takes your screen and puts it in the variable ScreenImage.
//	GrabImage(x, y, width, height);
var ScreenImage = GrabImage(0, 0, SW, SH);

//Let's render the map again BEFORE fading in to remove bugs.
//As you can see, you can leave == true away. It gives the same effect.
if (IsMapEngineRunning())
{
	RenderMap();
}

//FOR is a loop. The code within the accolades {} will loop until the condition is true.
//for(preparation. Here's where you make your values ready; condition; what should happen)
//The i < 255 means that the stuff between the {} keeps looping while our variable i is lower than 255.
//The i+=speed means that the value of our parameter speed is added to the variable i.
for (i = 0; i < 255; i+=speed)
{
	
	if (IsMapEngineRunning())
	{
		RenderMap();
	}
	//Create a color.
	//	CreateColor(R, G, B, transparency);
	//We make sure the transparency is our variable i!
	//Practically, you could make the RGB values read from parameter, to fade in ANY color. ;)
	FadeColor = CreateColor(0, 0, 0, i);
	
	//Let's blit our screen image now. With a color mask over it: our FadeColor.
	ScreenImage.blitMask(0, 0, FadeColor);
	FlipScreen();
//Close loop.
}
//Close function.
}



function FadeIn(speed, R, G, B)
{
var i = 255;
var FadeColor;
var SW = GetScreenWidth();
var SH = GetScreenHeight();

var Surface = GrabSurface(0,0,GetScreenWidth(),GetScreenHeight());
var SurfaceImage = Surface.createImage();

for (i = 255; i > 0; i-=speed)
{
	//The same code as the fade out, but reversed! i gets less now instead of more. The -= takes care of that.
	if (IsMapEngineRunning())
	{
		RenderMap();
	}

	FadeColor = CreateColor(0, 0, 0, i);
	SurfaceImage.blitMask(0,0, FadeColor);
	FlipScreen();
}
}


//Something you don't really need to understand. It just delays the engine for (parameter) milliseconds.
//Useful for waiting, for example in cutscenes or rendering (to get an animation).
function Delay(milliseconds)
{
  var start = GetTime();
  while (start + milliseconds > GetTime())
  {
  }
}


//	Vincent Beers, 2005
//	http://DaVince.websitemaster.org/
//	http://DaVince.sitesled.com/
//	Email: VincentBeers@yahoo.com